@@ -32,9 +32,13 @@ proc ModulesHelp { } {
 
 }
 
-# Environment
-setenv PODMAN_OPTS ""
-setenv PODMAN_COMMAND_OPTS ""
+# Environment - only set if not already defined
+if { ![info exists ::env(PODMAN_OPTS)] } {
+    setenv PODMAN_OPTS ""
+} 
+if { ![info exists ::env(PODMAN_COMMAND_OPTS)] } {
+    setenv PODMAN_COMMAND_OPTS ""
+} 
 
 # Variables
 
@@ -47,7 +51,7 @@ set workdir [pwd]
 {% if description %}set notes       "{{ description }}"{% endif %}
 {% if url %}set homepage    "{{ url }}"{% endif %}
 set helpcommand "This module is a {{ docker }} container wrapper for {{ name }} v{{ version }}. {% if description %}{{ description }}{% endif %}"
-{% if labels %}{% for key, value in labels.items() %}set {{ key }} {{ value }}
+{% if labels %}{% for key, value in labels.items() %}set {{ key }} "{{ value }}"
 {% endfor %}{% endif %}
 
 # conflict with modules with the same alias name
@@ -59,7 +63,7 @@ conflict {{ name }}
 set shellCmd "{{ command }} \${PODMAN_OPTS} run \${PODMAN_COMMAND_OPTS} -u `id -u`:`id -g` --rm -i{% if tty %}t{% endif %} --entrypoint {{ shell }} {% if envfile %}--env-file {{ module_dir }}/{{ envfile }}{% endif %} {% if bindpaths %}-v {{ bindpaths }} {% endif %}{% if features.home %}-v {{ features.home }} {% endif %} -v $workdir -w $workdir ${containerPath}" 
 
 # execCmd needs entrypoint to be the executor
-set execCmd "{{ command }} \${PODMAN_OPTS} run -i{% if tty %}t{% endif %} \${PODMAN_COMMAND_OPTS} -u `id -u`:`id -g` --rm {% if envfile %} --env-file {{ module_dir }}/{{ envfile }}{% endif %} {% if bindpaths %}-v {{ bindpaths }}{% endif %} -v $workdir -w $workdir"
+set execCmd "{{ command }} \${PODMAN_OPTS} run -i{% if tty %}t{% endif %} \${PODMAN_COMMAND_OPTS} -u `id -u`:`id -g` --rm {% if envfile %} --env-file {{ module_dir }}/{{ envfile }}{% endif %} {% if bindpaths %}-v {{ bindpaths }}{% endif %}{% if features.home %}-v {{ features.home }} {% endif %} -v $workdir -w $workdir"
 set runCmd "{{ command }} \${PODMAN_OPTS} run -i{% if tty %}t{% endif %} \${PODMAN_COMMAND_OPTS} -u `id -u`:`id -g` --rm {% if envfile %}--env-file  {{ module_dir }}/{{ envfile }}{% endif %} {% if bindpaths %}-v {{ bindpaths }} {% endif %}{% if features.home %}-v {{ features.home }} {% endif %} -v $workdir -w $workdir ${containerPath}"
 set inspectCmd "{{ command }} \${PODMAN_OPTS} inspect ${containerPath}" 
 
@@ -67,9 +71,21 @@ set inspectCmd "{{ command }} \${PODMAN_OPTS} inspect ${containerPath}"
 set-alias {|module_name|}-shell "${shellCmd}"
 
 # exec functions to provide "alias" to module commands
-{% if aliases %}{% for alias in aliases %}
-set-alias {{ alias.name }} "${execCmd} {% if alias.docker_options %} {{ alias.docker_options | replace("$", "\$") }} {% endif %} --entrypoint {{ alias.entrypoint | replace("$", "\$") }} ${containerPath} {{ alias.args | replace("$", "\$") }}"
-{% endfor %}{% endif %}
+{% if aliases %}
+if { [ module-info shell bash ] } {
+  if { [ module-info mode load ] } {
+{% for alias in aliases %}    puts stdout "function {{ alias.name }}() { ${execCmd} {% if alias.docker_options %} {{ alias.docker_options | replace("$", "\$") }} {% endif %} --entrypoint {{ alias.entrypoint | replace("$", "\$") }} ${containerPath} {{ alias.args | replace("$", "\$") }} \$@; }; export -f {{ alias.name }};"
+{% endfor %}
+  }
+  if { [ module-info mode remove ] } {
+{% for alias in aliases %}    puts stdout "unset -f {{ alias.name }};"
+{% endfor %}
+  }
+} else {
+{% for alias in aliases %}  set-alias {{ alias.name }} "${execCmd} {% if alias.docker_options %} {{ alias.docker_options | replace("$", "\$") }} {% endif %} --entrypoint {{ alias.entrypoint | replace("$", "\$") }} ${containerPath} {{ alias.args | replace("$", "\$") }}"
+{% endfor %}
+}
+{% endif %}
 
 # A customizable exec function
 set-alias {|module_name|}-exec "${execCmd} --entrypoint \"\" ${containerPath}"
